@@ -3,9 +3,9 @@ import logging
 
 from django.conf import settings
 from django.core.cache.backends.base import BaseCache
+from django.utils.module_loading import import_string
 
 from .exceptions import ConnectionInterrupted
-from .util import load_class
 
 DJANGO_REDIS_IGNORE_EXCEPTIONS = getattr(settings, "DJANGO_REDIS_IGNORE_EXCEPTIONS", False)
 DJANGO_REDIS_LOG_IGNORED_EXCEPTIONS = getattr(settings, "DJANGO_REDIS_LOG_IGNORED_EXCEPTIONS", False)
@@ -14,7 +14,7 @@ DJANGO_REDIS_SCAN_ITERSIZE = getattr(settings, "DJANGO_REDIS_SCAN_ITERSIZE", 10)
 
 
 if DJANGO_REDIS_LOG_IGNORED_EXCEPTIONS:
-    logger = logging.getLogger((DJANGO_REDIS_LOGGER or __name__))
+    logger = logging.getLogger(DJANGO_REDIS_LOGGER or __name__)
 
 
 def omit_exception(method=None, return_value=None):
@@ -42,13 +42,13 @@ def omit_exception(method=None, return_value=None):
 
 class RedisCache(BaseCache):
     def __init__(self, server, params):
-        super(RedisCache, self).__init__(params)
+        super().__init__(params)
         self._server = server
         self._params = params
 
         options = params.get("OPTIONS", {})
         self._client_cls = options.get("CLIENT_CLASS", "django_redis.client.DefaultClient")
-        self._client_cls = load_class(self._client_cls)
+        self._client_cls = import_string(self._client_cls)
         self._client = None
 
         self._ignore_exceptions = options.get("IGNORE_EXCEPTIONS", DJANGO_REDIS_IGNORE_EXCEPTIONS)
