@@ -1,7 +1,3 @@
-# -*- coding: utf-8 -*-
-
-from __future__ import absolute_import, unicode_literals
-
 import random
 import re
 import socket
@@ -10,13 +6,13 @@ from collections import OrderedDict
 from django.conf import settings
 from django.core.cache.backends.base import DEFAULT_TIMEOUT, get_key_func
 from django.core.exceptions import ImproperlyConfigured
-from django.utils import six
 from django.utils.encoding import smart_text
+from django.utils.module_loading import import_string
 from redis.exceptions import ConnectionError, ResponseError, TimeoutError
 
 from .. import pool
 from ..exceptions import CompressorError, ConnectionInterrupted
-from ..util import CacheKey, load_class
+from ..util import CacheKey
 
 _main_exceptions = (TimeoutError, ResponseError, ConnectionError, socket.timeout)
 
@@ -28,7 +24,7 @@ def glob_escape(s):
     return special_re.sub(r'[\1]', s)
 
 
-class DefaultClient(object):
+class DefaultClient:
     def __init__(self, server, params, backend):
         self._backend = backend
         self._server = server
@@ -49,10 +45,10 @@ class DefaultClient(object):
         self._slave_read_only = self._options.get('SLAVE_READ_ONLY', True)
 
         serializer_path = self._options.get("SERIALIZER", "django_redis.serializers.pickle.PickleSerializer")
-        serializer_cls = load_class(serializer_path)
+        serializer_cls = import_string(serializer_path)
 
         compressor_path = self._options.get("COMPRESSOR", "django_redis.compressors.identity.IdentityCompressor")
-        compressor_cls = load_class(compressor_path)
+        compressor_cls = import_string(compressor_path)
 
         self._serializer = serializer_cls(options=self._options)
         self._compressor = compressor_cls(options=self._options)
@@ -114,7 +110,7 @@ class DefaultClient(object):
         nkey = self.make_key(key, version=version)
         nvalue = self.encode(value)
 
-        if timeout == DEFAULT_TIMEOUT:
+        if timeout is DEFAULT_TIMEOUT:
             timeout = self._backend.default_timeout
 
         original_client = client
@@ -140,7 +136,7 @@ class DefaultClient(object):
                             # than to set it and than expire in a pipeline
                             return self.delete(key, client=client, version=version)
 
-                return client.set(nkey, nvalue, nx=nx, px=timeout, xx=xx)
+                return bool(client.set(nkey, nvalue, nx=nx, px=timeout, xx=xx))
             except _main_exceptions as e:
                 if not original_client and not self._slave_read_only and len(tried) < len(self._server):
                     tried.append(index)
@@ -323,7 +319,7 @@ class DefaultClient(object):
         Encode the given value.
         """
 
-        if isinstance(value, bool) or not isinstance(value, six.integer_types):
+        if isinstance(value, bool) or not isinstance(value, int):
             value = self._serializer.dumps(value)
             value = self._compressor.compress(value)
             return value
