@@ -1,13 +1,8 @@
-# -*- coding: utf-8 -*-
-
-from __future__ import absolute_import, unicode_literals
-
 import re
 from collections import OrderedDict
 
 from django.conf import settings
 from django.utils.encoding import smart_text
-from django.utils.six import text_type
 from redis.exceptions import ConnectionError
 
 from ..exceptions import ConnectionInterrupted
@@ -20,7 +15,7 @@ class ShardClient(DefaultClient):
     _findhash = re.compile(r'.*\{(.*)\}.*', re.I)
 
     def __init__(self, *args, **kwargs):
-        super(ShardClient, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
         if not isinstance(self._server, (list, tuple)):
             self._server = [self._server]
@@ -38,7 +33,7 @@ class ShardClient(DefaultClient):
         return connection_dict
 
     def get_server_name(self, _key):
-        key = text_type(_key)
+        key = str(_key)
         g = self._findhash.match(key)
         if g is not None and len(g.groups()) > 0:
             key = g.groups()[0]
@@ -54,7 +49,7 @@ class ShardClient(DefaultClient):
             key = self.make_key(key, version=version)
             client = self.get_server(key)
 
-        return super(ShardClient, self)\
+        return super()\
             .add(key=key, value=value, version=version, client=client, timeout=timeout)
 
     def get(self, key, default=None, version=None, client=None):
@@ -62,7 +57,7 @@ class ShardClient(DefaultClient):
             key = self.make_key(key, version=version)
             client = self.get_server(key)
 
-        return super(ShardClient, self)\
+        return super()\
             .get(key=key, default=default, version=version, client=client)
 
     def get_many(self, keys, version=None):
@@ -92,9 +87,9 @@ class ShardClient(DefaultClient):
             key = self.make_key(key, version=version)
             client = self.get_server(key)
 
-        return super(ShardClient, self).set(key=key, value=value,
-                                            timeout=timeout, version=version,
-                                            client=client, nx=nx)
+        return super().set(key=key, value=value,
+                           timeout=timeout, version=version,
+                           client=client, nx=nx)
 
     def set_many(self, data, timeout=DEFAULT_TIMEOUT, version=None):
         """
@@ -127,7 +122,7 @@ class ShardClient(DefaultClient):
             key = self.make_key(key, version=version)
             client = self.get_server(key)
 
-        return super(ShardClient, self).delete(key=key, version=version, client=client)
+        return super().delete(key=key, version=version, client=client)
 
     def ttl(self, key, version=None, client=None):
         """
@@ -139,22 +134,22 @@ class ShardClient(DefaultClient):
             key = self.make_key(key, version=version)
             client = self.get_server(key)
 
-        return super(ShardClient, self).ttl(key=key, version=version, client=client)
+        return super().ttl(key=key, version=version, client=client)
 
     def persist(self, key, version=None, client=None):
         if client is None:
             key = self.make_key(key, version=version)
             client = self.get_server(key)
 
-        return super(ShardClient, self).persist(key=key, version=version, client=client)
+        return super().persist(key=key, version=version, client=client)
 
     def expire(self, key, timeout, version=None, client=None):
         if client is None:
             key = self.make_key(key, version=version)
             client = self.get_server(key)
 
-        return super(ShardClient, self).expire(key=key, timeout=timeout,
-                                               version=version, client=client)
+        return super().expire(key=key, timeout=timeout,
+                              version=version, client=client)
 
     def lock(self, key, version=None, timeout=None, sleep=0.1,
              blocking_timeout=None, client=None):
@@ -164,8 +159,8 @@ class ShardClient(DefaultClient):
             client = self.get_server(key)
 
         key = self.make_key(key, version=version)
-        return super(ShardClient, self).lock(key, timeout=timeout, sleep=sleep, client=client,
-                                             blocking_timeout=blocking_timeout)
+        return super().lock(key, timeout=timeout, sleep=sleep, client=client,
+                            blocking_timeout=blocking_timeout)
 
     def delete_many(self, keys, version=None):
         """
@@ -210,7 +205,7 @@ class ShardClient(DefaultClient):
             key = self.make_key(key, version=version)
             client = self.get_server(key)
 
-        return super(ShardClient, self)\
+        return super()\
             .incr(key=key, delta=delta, version=version, client=client)
 
     def decr(self, key, delta=1, version=None, client=None):
@@ -218,14 +213,14 @@ class ShardClient(DefaultClient):
             key = self.make_key(key, version=version)
             client = self.get_server(key)
 
-        return super(ShardClient, self)\
+        return super()\
             .decr(key=key, delta=delta, version=version, client=client)
 
     def iter_keys(self, key, version=None):
         raise NotImplementedError("iter_keys not supported on sharded client")
 
     def keys(self, search, version=None):
-        pattern = self.make_key(search, version=version)
+        pattern = self.make_pattern(search, version=version)
         keys = []
         try:
             for server, connection in self._serverdict.items():
@@ -262,3 +257,11 @@ class ShardClient(DefaultClient):
             for client in self._serverdict.values():
                 for c in client.connection_pool._available_connections:
                     c.disconnect()
+
+    def touch(self, key, timeout=DEFAULT_TIMEOUT, version=None, client=None):
+        if client is None:
+            key = self.make_key(key, version=version)
+            client = self.get_server(key)
+
+        return super().touch(key=key, timeout=timeout,
+                             version=version, client=client)
