@@ -1,6 +1,3 @@
-# -*- coding: utf-8 -*-
-
-
 class ConnectionInterrupted(Exception):
     def __init__(self, connection, parent=None):
         self.connection = connection
@@ -14,7 +11,7 @@ class ConnectionInterrupted(Exception):
             error_type = self.parent.__class__.__name__
             error_msg = str(self.parent)
 
-        return "Redis %s: %s" % (error_type, error_msg)
+        return "Redis {}: {}".format(error_type, error_msg)
 
 
 class CompressorError(Exception):
