@@ -1,7 +1,3 @@
-# -*- coding: utf-8 -*-
-
-from __future__ import absolute_import, unicode_literals
-
 import json
 
 from django.core.serializers.json import DjangoJSONEncoder
