@@ -1,21 +1,17 @@
-# -*- coding: utf-8 -*-
-
-from __future__ import absolute_import, print_function, unicode_literals
-
 import base64
 import copy
 import datetime
 import time
 import unittest
 from datetime import timedelta
+from unittest.mock import Mock, patch
 
 from django import VERSION
 from django.conf import settings
 from django.contrib.sessions.backends.cache import SessionStore as CacheSession
 from django.core.cache import DEFAULT_CACHE_ALIAS, cache, caches
 from django.test import override_settings
-from django.test.utils import patch_logger
-from django.utils import six, timezone
+from django.utils import timezone
 from redis.exceptions import ConnectionError
 
 import django_redis.cache
@@ -24,17 +20,8 @@ from django_redis.client import DefaultClient, ShardClient, herd
 from django_redis.serializers.json import JSONSerializer
 from django_redis.serializers.msgpack import MSGPackSerializer
 
-try:
-    from unittest.mock import patch, Mock
-except ImportError:
-    from mock import patch, Mock
-
-
 herd.CACHE_HERD_TIMEOUT = 2
 
-if six.PY3:
-    long = int
-
 
 def make_key(key, prefix, version):
     return "{}#{}#{}".format(prefix, version, key)
@@ -90,7 +77,7 @@ class DjangoRedisCacheTestEscapePrefix(unittest.TestCase):
 
     def test_iter_keys(self):
         if isinstance(self.cache.client, ShardClient):
-            raise unittest.SkipTest("ShardClient doesn't support iter_keys")
+            self.skipTest("ShardClient doesn't support iter_keys")
 
         self.cache.set('a', '1')
         self.other.set('b', '2')
@@ -120,6 +107,9 @@ class DjangoRedisCacheTestCustomKeyFunction(unittest.TestCase):
             pass
 
     def test_custom_key_function(self):
+        if isinstance(self.cache.client, ShardClient):
+            self.skipTest("ShardClient doesn't support get_client")
+
         for key in ["foo-aa", "foo-ab", "foo-bb", "foo-bc"]:
             self.cache.set(key, "foo")
 
@@ -129,13 +119,9 @@ class DjangoRedisCacheTestCustomKeyFunction(unittest.TestCase):
         keys = self.cache.keys("foo*")
         self.assertEqual(set(keys), {"foo-bb", "foo-bc"})
         # ensure our custom function was actually called
-        try:
-            self.assertEqual(
-                {k.decode('utf-8') for k in self.cache.raw_client.keys('*')},
-                {'#1#foo-bc', '#1#foo-bb'})
-        except (NotImplementedError, AttributeError):
-            # not all clients support .keys()
-            pass
+        self.assertEqual(
+            {k.decode() for k in self.cache.client.get_client(write=False).keys('*')},
+            {'#1#foo-bc', '#1#foo-bb'})
 
 
 class DjangoRedisCacheTests(unittest.TestCase):
@@ -150,8 +136,8 @@ class DjangoRedisCacheTests(unittest.TestCase):
     def test_setnx(self):
         # we should ensure there is no test_key_nx in redis
         self.cache.delete("test_key_nx")
-        res = self.cache.get("test_key_nx", None)
-        self.assertEqual(res, None)
+        res = self.cache.get("test_key_nx")
+        self.assertIsNone(res)
 
         res = self.cache.set("test_key_nx", 1, nx=True)
         self.assertTrue(res)
@@ -162,28 +148,28 @@ class DjangoRedisCacheTests(unittest.TestCase):
         self.assertEqual(res, 1)
 
         self.cache.delete("test_key_nx")
-        res = self.cache.get("test_key_nx", None)
-        self.assertEqual(res, None)
+        res = self.cache.get("test_key_nx")
+        self.assertIsNone(res)
 
     def test_setnx_timeout(self):
         # test that timeout still works for nx=True
         res = self.cache.set("test_key_nx", 1, timeout=2, nx=True)
         self.assertTrue(res)
         time.sleep(3)
-        res = self.cache.get("test_key_nx", None)
-        self.assertEqual(res, None)
+        res = self.cache.get("test_key_nx")
+        self.assertIsNone(res)
 
         # test that timeout will not affect key, if it was there
         self.cache.set("test_key_nx", 1)
         res = self.cache.set("test_key_nx", 2, timeout=2, nx=True)
         self.assertFalse(res)
         time.sleep(3)
-        res = self.cache.get("test_key_nx", None)
+        res = self.cache.get("test_key_nx")
         self.assertEqual(res, 1)
 
         self.cache.delete("test_key_nx")
-        res = self.cache.get("test_key_nx", None)
-        self.assertEqual(res, None)
+        res = self.cache.get("test_key_nx")
+        self.assertIsNone(res)
 
     def test_unicode_keys(self):
         self.cache.set('ключ', 'value')
@@ -201,21 +187,20 @@ class DjangoRedisCacheTests(unittest.TestCase):
         self.cache.set("test_key", "hello" * 1000)
         res = self.cache.get("test_key")
 
-        type(res)
-        self.assertIsInstance(res, six.text_type)
+        self.assertIsInstance(res, str)
         self.assertEqual(res, "hello" * 1000)
 
         self.cache.set("test_key", "2")
         res = self.cache.get("test_key")
 
-        self.assertIsInstance(res, six.text_type)
+        self.assertIsInstance(res, str)
         self.assertEqual(res, "2")
 
     def test_save_unicode(self):
         self.cache.set("test_key", "heló")
         res = self.cache.get("test_key")
 
-        self.assertIsInstance(res, six.text_type)
+        self.assertIsInstance(res, str)
         self.assertEqual(res, "heló")
 
     def test_save_dict(self):
@@ -249,60 +234,64 @@ class DjangoRedisCacheTests(unittest.TestCase):
         self.cache.set("test_key", 222, timeout=3)
         time.sleep(4)
 
-        res = self.cache.get("test_key", None)
-        self.assertEqual(res, None)
+        res = self.cache.get("test_key")
+        self.assertIsNone(res)
 
     def test_timeout_0(self):
         self.cache.set("test_key", 222, timeout=0)
-        res = self.cache.get("test_key", None)
-        self.assertEqual(res, None)
+        res = self.cache.get("test_key")
+        self.assertIsNone(res)
 
     def test_timeout_parameter_as_positional_argument(self):
         self.cache.set("test_key", 222, -1)
-        res = self.cache.get("test_key", None)
+        res = self.cache.get("test_key")
         self.assertIsNone(res)
 
         self.cache.set("test_key", 222, 1)
-        res1 = self.cache.get("test_key", None)
+        res1 = self.cache.get("test_key")
         time.sleep(2)
-        res2 = self.cache.get("test_key", None)
+        res2 = self.cache.get("test_key")
         self.assertEqual(res1, 222)
-        self.assertEqual(res2, None)
+        self.assertIsNone(res2)
 
         # nx=True should not overwrite expire of key already in db
         self.cache.set("test_key", 222, None)
         self.cache.set("test_key", 222, -1, nx=True)
-        res = self.cache.get("test_key", None)
+        res = self.cache.get("test_key")
         self.assertEqual(res, 222)
 
     def test_timeout_negative(self):
         self.cache.set("test_key", 222, timeout=-1)
-        res = self.cache.get("test_key", None)
+        res = self.cache.get("test_key")
         self.assertIsNone(res)
 
         self.cache.set("test_key", 222, timeout=None)
         self.cache.set("test_key", 222, timeout=-1)
-        res = self.cache.get("test_key", None)
+        res = self.cache.get("test_key")
         self.assertIsNone(res)
 
         # nx=True should not overwrite expire of key already in db
         self.cache.set("test_key", 222, timeout=None)
         self.cache.set("test_key", 222, timeout=-1, nx=True)
-        res = self.cache.get("test_key", None)
+        res = self.cache.get("test_key")
         self.assertEqual(res, 222)
 
     def test_timeout_tiny(self):
         self.cache.set("test_key", 222, timeout=0.00001)
-        res = self.cache.get("test_key", None)
+        res = self.cache.get("test_key")
         self.assertIn(res, (None, 222))
 
     def test_set_add(self):
         self.cache.set("add_key", "Initial value")
-        self.cache.add("add_key", "New value")
-        res = cache.get("add_key")
+        res = self.cache.add("add_key", "New value")
+        self.assertIs(res, False)
 
+        res = cache.get("add_key")
         self.assertEqual(res, "Initial value")
 
+        res = self.cache.add("other_key", "New value")
+        self.assertIs(res, True)
+
     def test_get_many(self):
         self.cache.set("a", 1)
         self.cache.set("b", 2)
@@ -362,149 +351,145 @@ class DjangoRedisCacheTests(unittest.TestCase):
         self.assertFalse(bool(res))
 
     def test_incr(self):
-        try:
-            self.cache.set("num", 1)
+        if isinstance(self.cache.client, herd.HerdClient):
+            self.skipTest("HerdClient doesn't support incr")
 
-            self.cache.incr("num")
-            res = self.cache.get("num")
-            self.assertEqual(res, 2)
+        self.cache.set("num", 1)
 
-            self.cache.incr("num", 10)
-            res = self.cache.get("num")
-            self.assertEqual(res, 12)
+        self.cache.incr("num")
+        res = self.cache.get("num")
+        self.assertEqual(res, 2)
 
-            # max 64 bit signed int
-            self.cache.set("num", 9223372036854775807)
+        self.cache.incr("num", 10)
+        res = self.cache.get("num")
+        self.assertEqual(res, 12)
 
-            self.cache.incr("num")
-            res = self.cache.get("num")
-            self.assertEqual(res, 9223372036854775808)
+        # max 64 bit signed int
+        self.cache.set("num", 9223372036854775807)
 
-            self.cache.incr("num", 2)
-            res = self.cache.get("num")
-            self.assertEqual(res, 9223372036854775810)
+        self.cache.incr("num")
+        res = self.cache.get("num")
+        self.assertEqual(res, 9223372036854775808)
 
-            self.cache.set("num", long(3))
+        self.cache.incr("num", 2)
+        res = self.cache.get("num")
+        self.assertEqual(res, 9223372036854775810)
 
-            self.cache.incr("num", 2)
-            res = self.cache.get("num")
-            self.assertEqual(res, 5)
+        self.cache.set("num", 3)
 
-        except NotImplementedError as e:
-            print(e)
+        self.cache.incr("num", 2)
+        res = self.cache.get("num")
+        self.assertEqual(res, 5)
 
     def test_incr_error(self):
-        try:
-            with self.assertRaises(ValueError):
-                # key does not exist
-                self.cache.incr('numnum')
-        except NotImplementedError:
-            raise unittest.SkipTest("`incr` not supported in herd client")
+        if isinstance(self.cache.client, herd.HerdClient):
+            self.skipTest("HerdClient doesn't support incr")
+
+        with self.assertRaises(ValueError):
+            # key does not exist
+            self.cache.incr('numnum')
 
     def test_incr_ignore_check(self):
-        try:
-            # incr with 'ignore_key_check' is supported only on the DefaultClient
-            if isinstance(self.cache, DefaultClient):
-                # key exists check will be skipped and the value will be incremented by '1' which is the default delta
-                self.cache.incr("num", ignore_key_check=True)
-                res = self.cache.get("num")
-                self.assertEqual(res, 1)
-                self.cache.delete("num")
+        if isinstance(self.cache.client, ShardClient):
+            self.skipTest("ShardClient doesn't support argument ignore_key_check to incr")
+        if isinstance(self.cache.client, herd.HerdClient):
+            self.skipTest("HerdClient doesn't support incr")
 
-                # since key doesnt exist it is set to the delta value, 10 in this case
-                self.cache.incr("num", 10, ignore_key_check=True)
-                res = self.cache.get("num")
-                self.assertEqual(res, 10)
-                self.cache.delete("num")
+        # key exists check will be skipped and the value will be incremented by '1' which is the default delta
+        self.cache.incr("num", ignore_key_check=True)
+        res = self.cache.get("num")
+        self.assertEqual(res, 1)
+        self.cache.delete("num")
 
-                # following are just regression checks to make sure it still works as expected with incr
-                # max 64 bit signed int
-                self.cache.set("num", 9223372036854775807)
+        # since key doesnt exist it is set to the delta value, 10 in this case
+        self.cache.incr("num", 10, ignore_key_check=True)
+        res = self.cache.get("num")
+        self.assertEqual(res, 10)
+        self.cache.delete("num")
 
-                self.cache.incr("num", ignore_key_check=True)
-                res = self.cache.get("num")
-                self.assertEqual(res, 9223372036854775808)
+        # following are just regression checks to make sure it still works as expected with incr
+        # max 64 bit signed int
+        self.cache.set("num", 9223372036854775807)
 
-                self.cache.incr("num", 2, ignore_key_check=True)
-                res = self.cache.get("num")
-                self.assertEqual(res, 9223372036854775810)
+        self.cache.incr("num", ignore_key_check=True)
+        res = self.cache.get("num")
+        self.assertEqual(res, 9223372036854775808)
 
-                self.cache.set("num", long(3))
+        self.cache.incr("num", 2, ignore_key_check=True)
+        res = self.cache.get("num")
+        self.assertEqual(res, 9223372036854775810)
 
-                self.cache.incr("num", 2, ignore_key_check=True)
-                res = self.cache.get("num")
-                self.assertEqual(res, 5)
-        except NotImplementedError:
-            raise unittest.SkipTest("`incr` not supported in herd client")
+        self.cache.set("num", 3)
+
+        self.cache.incr("num", 2, ignore_key_check=True)
+        res = self.cache.get("num")
+        self.assertEqual(res, 5)
 
     def test_get_set_bool(self):
         self.cache.set("bool", True)
         res = self.cache.get("bool")
 
         self.assertIsInstance(res, bool)
-        self.assertEqual(res, True)
+        self.assertIs(res, True)
 
         self.cache.set("bool", False)
         res = self.cache.get("bool")
 
         self.assertIsInstance(res, bool)
-        self.assertEqual(res, False)
+        self.assertIs(res, False)
 
     def test_decr(self):
-        try:
-            self.cache.set("num", 20)
+        if isinstance(self.cache.client, herd.HerdClient):
+            self.skipTest("HerdClient doesn't support decr")
 
-            self.cache.decr("num")
-            res = self.cache.get("num")
-            self.assertEqual(res, 19)
+        self.cache.set("num", 20)
 
-            self.cache.decr("num", 20)
-            res = self.cache.get("num")
-            self.assertEqual(res, -1)
+        self.cache.decr("num")
+        res = self.cache.get("num")
+        self.assertEqual(res, 19)
 
-            self.cache.decr("num", long(2))
-            res = self.cache.get("num")
-            self.assertEqual(res, -3)
+        self.cache.decr("num", 20)
+        res = self.cache.get("num")
+        self.assertEqual(res, -1)
 
-            self.cache.set("num", long(20))
+        self.cache.decr("num", 2)
+        res = self.cache.get("num")
+        self.assertEqual(res, -3)
 
-            self.cache.decr("num")
-            res = self.cache.get("num")
-            self.assertEqual(res, 19)
+        self.cache.set("num", 20)
 
-            # max 64 bit signed int + 1
-            self.cache.set("num", 9223372036854775808)
+        self.cache.decr("num")
+        res = self.cache.get("num")
+        self.assertEqual(res, 19)
 
-            self.cache.decr("num")
-            res = self.cache.get("num")
-            self.assertEqual(res, 9223372036854775807)
+        # max 64 bit signed int + 1
+        self.cache.set("num", 9223372036854775808)
 
-            self.cache.decr("num", 2)
-            res = self.cache.get("num")
-            self.assertEqual(res, 9223372036854775805)
-        except NotImplementedError as e:
-            print(e)
+        self.cache.decr("num")
+        res = self.cache.get("num")
+        self.assertEqual(res, 9223372036854775807)
+
+        self.cache.decr("num", 2)
+        res = self.cache.get("num")
+        self.assertEqual(res, 9223372036854775805)
 
     def test_version(self):
         self.cache.set("keytest", 2, version=2)
         res = self.cache.get("keytest")
-        self.assertEqual(res, None)
+        self.assertIsNone(res)
 
         res = self.cache.get("keytest", version=2)
         self.assertEqual(res, 2)
 
     def test_incr_version(self):
-        try:
-            self.cache.set("keytest", 2)
-            self.cache.incr_version("keytest")
+        self.cache.set("keytest", 2)
+        self.cache.incr_version("keytest")
 
-            res = self.cache.get("keytest")
-            self.assertEqual(res, None)
+        res = self.cache.get("keytest")
+        self.assertIsNone(res)
 
-            res = self.cache.get("keytest", version=2)
-            self.assertEqual(res, 2)
-        except NotImplementedError as e:
-            print(e)
+        res = self.cache.get("keytest", version=2)
+        self.assertEqual(res, 2)
 
     def test_delete_pattern(self):
         for key in ["foo-aa", "foo-ab", "foo-bb", "foo-bc"]:
@@ -545,19 +530,12 @@ class DjangoRedisCacheTests(unittest.TestCase):
 
     def test_ttl(self):
         cache = caches["default"]
-        _params = cache._params
-        _is_herd = _params["OPTIONS"]["CLIENT_CLASS"] == "django_redis.client.HerdClient"
-        _is_shard = _params["OPTIONS"]["CLIENT_CLASS"] == "django_redis.client.ShardClient"
-
-        # Not supported for shard client.
-        if _is_shard:
-            return
 
         # Test ttl
         cache.set("foo", "bar", 10)
         ttl = cache.ttl("foo")
 
-        if _is_herd:
+        if isinstance(cache.client, herd.HerdClient):
             self.assertAlmostEqual(ttl, 12)
         else:
             self.assertAlmostEqual(ttl, 10)
@@ -565,7 +543,7 @@ class DjangoRedisCacheTests(unittest.TestCase):
         # Test ttl None
         cache.set("foo", "foo", timeout=None)
         ttl = cache.ttl("foo")
-        self.assertEqual(ttl, None)
+        self.assertIsNone(ttl)
 
         # Test ttl with expired key
         cache.set("foo", "foo", timeout=-1)
@@ -599,11 +577,8 @@ class DjangoRedisCacheTests(unittest.TestCase):
 
     def test_iter_keys(self):
         cache = caches["default"]
-        _params = cache._params
-        _is_shard = _params["OPTIONS"]["CLIENT_CLASS"] == "django_redis.client.ShardClient"
-
-        if _is_shard:
-            return
+        if isinstance(cache.client, ShardClient):
+            self.skipTest("ShardClient doesn't support iter_keys")
 
         cache.set("foo1", 1)
         cache.set("foo2", 1)
@@ -622,44 +597,41 @@ class DjangoRedisCacheTests(unittest.TestCase):
         self.assertNotEqual(next(result), None)
 
     def test_master_slave_switching(self):
-        try:
-            cache = caches["sample"]
-            client = cache.client
-            client._server = ["foo", "bar"]
-            client._clients = ["Foo", "Bar"]
+        if isinstance(self.cache.client, ShardClient):
+            self.skipTest("ShardClient doesn't support get_client")
 
-            self.assertEqual(client.get_client(write=True), "Foo")
-            self.assertEqual(client.get_client(write=False), "Bar")
-        except NotImplementedError:
-            pass
+        cache = caches["sample"]
+        client = cache.client
+        client._server = ["foo", "bar"]
+        client._clients = ["Foo", "Bar"]
+
+        self.assertEqual(client.get_client(write=True), "Foo")
+        self.assertEqual(client.get_client(write=False), "Bar")
 
     def test_touch_zero_timeout(self):
         self.cache.set("test_key", 222, timeout=10)
 
-        self.assertEqual(self.cache.touch("test_key", 0), True)
-        res = self.cache.get("test_key", None)
-        self.assertEqual(res, None)
+        self.assertIs(self.cache.touch("test_key", 0), True)
+        res = self.cache.get("test_key")
+        self.assertIsNone(res)
 
     def test_touch_positive_timeout(self):
         self.cache.set("test_key", 222, timeout=10)
 
-        self.cache.touch("test_key", 2)
-        self.assertEqual(self.cache.touch("test_key", 2), True)
-        res1 = self.cache.get("test_key", None)
-        time.sleep(2)
-        res2 = self.cache.get("test_key", None)
-        self.assertEqual(res1, 222)
-        self.assertEqual(res2, None)
+        self.assertIs(self.cache.touch("test_key", 2), True)
+        self.assertEqual(self.cache.get("test_key"), 222)
+        time.sleep(3)
+        self.assertIsNone(self.cache.get("test_key"))
 
     def test_touch_negative_timeout(self):
         self.cache.set("test_key", 222, timeout=10)
 
-        self.assertEqual(self.cache.touch("test_key", -1), True)
-        res = self.cache.get("test_key", None)
-        self.assertEqual(res, None)
+        self.assertIs(self.cache.touch("test_key", -1), True)
+        res = self.cache.get("test_key")
+        self.assertIsNone(res)
 
     def test_touch_missed_key(self):
-        self.assertEqual(self.cache.touch("test_key", -1), False)
+        self.assertIs(self.cache.touch("test_key", -1), False)
 
 
 class DjangoOmitExceptionsTests(unittest.TestCase):
@@ -792,7 +764,7 @@ class SessionTestsMixin:
         self.session.update({'update key': 1})
         self.assertIs(self.session.accessed, True)
         self.assertIs(self.session.modified, True)
-        self.assertEqual(self.session.get('update key', None), 1)
+        self.assertEqual(self.session.get('update key'), 1)
 
     def test_has_key(self):
         self.session['some key'] = 1
@@ -1002,12 +974,11 @@ class SessionTestsMixin:
         self.assertEqual(self.session.decode(encoded), data)
 
     def test_decode_failure_logged_to_security(self):
-        bad_encode = base64.b64encode(b'flaskdj:alkdjf').decode()
-        with patch_logger('django.security.SuspiciousSession', 'warning') as calls:
+        bad_encode = base64.b64encode(b'flaskdj:alkdjf').decode('ascii')
+        with self.assertLogs('django.security.SuspiciousSession', 'WARNING') as cm:
             self.assertEqual({}, self.session.decode(bad_encode))
-            # check that the failed decode is logged
-            self.assertEqual(len(calls), 1)
-            self.assertIn('corrupted', calls[0])
+        # The failed decode is logged.
+        self.assertIn('corrupted', cm.output[0])
 
     def test_actual_expiry(self):
         # this doesn't work with JSONSerializer (serializing timedelta)
@@ -1069,17 +1040,14 @@ class SessionTestsMixin:
 
         self.assertEqual(s1.load(), {})
 
-    if six.PY2:
-        assertCountEqual = unittest.TestCase.assertItemsEqual
-
 
 class SessionTests(SessionTestsMixin, unittest.TestCase):
     backend = CacheSession
 
     def test_actual_expiry(self):
         if isinstance(caches[DEFAULT_CACHE_ALIAS].client._serializer, MSGPackSerializer):
-            raise unittest.SkipTest("msgpack serializer doesn't support datetime serialization")
-        super(SessionTests, self).test_actual_expiry()
+            self.skipTest("msgpack serializer doesn't support datetime serialization")
+        super().test_actual_expiry()
 
 
 class TestDefaultClient(unittest.TestCase):
