@@ -1,16 +1,14 @@
-# -*- coding: utf-8 -*-
-
 import unittest
 
 from django_redis.hash_ring import HashRing
 
 
-class Node(object):
+class Node:
     def __init__(self, id):
         self.id = id
 
     def __str__(self):
-        return "node:{0}".format(self.id)
+        return "node:{}".format(self.id)
 
     def __repr__(self):
         return "<Node {}>".format(self.id)
@@ -28,12 +26,12 @@ class HashRingTest(unittest.TestCase):
     def test_hashring(self):
         ids = []
 
-        for key in ["test{0}".format(x) for x in range(10)]:
+        for key in ["test{}".format(x) for x in range(10)]:
             node = self.ring.get_node(key)
             ids.append(node.id)
 
         self.assertEqual(ids, [0, 2, 1, 2, 2, 2, 2, 0, 1, 1])
 
     def test_hashring_brute_force(self):
-        for key in ("test{0}".format(x) for x in range(10000)):
+        for key in ("test{}".format(x) for x in range(10000)):
             self.ring.get_node(key)
