@@ -20,7 +20,7 @@ CACHES = {
     },
     "sample": {
         "BACKEND": "django_redis.cache.RedisCache",
-        "LOCATION": "127.0.0.1:6379:1,127.0.0.1:6379:1",
+        "LOCATION": "redis://127.0.0.1:6379:1,redis://127.0.0.1:6379:1",
         "OPTIONS": {
             "CLIENT_CLASS": "django_redis.client.DefaultClient",
         }
