@@ -4,7 +4,7 @@ CACHES = {
     'default': {
         'BACKEND': 'django_redis.cache.RedisCache',
         'LOCATION': [
-            '127.0.0.1:6379:5',
+            'redis://127.0.0.1:6379?db=5',
         ],
         'OPTIONS': {
             'CLIENT_CLASS': 'django_redis.client.HerdClient',
@@ -19,7 +19,7 @@ CACHES = {
     },
     'sample': {
         'BACKEND': 'django_redis.cache.RedisCache',
-        'LOCATION': '127.0.0.1:6379:1,127.0.0.1:6379:1',
+        'LOCATION': 'redis://127.0.0.1:6379?db=1,redis://127.0.0.1:6379?db=1',
         'OPTIONS': {
             'CLIENT_CLASS': 'django_redis.client.HerdClient',
         }
