@@ -4,8 +4,8 @@ CACHES = {
     'default': {
         'BACKEND': 'django_redis.cache.RedisCache',
         'LOCATION': [
-            '127.0.0.1:6379:1',
-            '127.0.0.1:6379:2',
+            'redis://127.0.0.1:6379?db=1',
+            'redis://127.0.0.1:6379?db=2',
         ],
         'OPTIONS': {
             'CLIENT_CLASS': 'django_redis.client.ShardClient',
@@ -23,7 +23,7 @@ CACHES = {
     },
     'sample': {
         'BACKEND': 'django_redis.cache.RedisCache',
-        'LOCATION': '127.0.0.1:6379:1,127.0.0.1:6379:1',
+        'LOCATION': 'redis://127.0.0.1:6379?db=1,redis://127.0.0.1:6379?db=1',
         'OPTIONS': {
             'CLIENT_CLASS': 'django_redis.client.ShardClient',
         }
