@@ -20,7 +20,7 @@ CACHES = {
     },
     'sample': {
         'BACKEND': 'redis_cache.cache.RedisCache',
-        'LOCATION': '127.0.0.1:6379:1,127.0.0.1:6379:1',
+        'LOCATION': 'redis://127.0.0.1:6379?db=1,redis://127.0.0.1:6379?db=1',
         'OPTIONS': {
             'CLIENT_CLASS': 'redis_cache.client.DefaultClient',
         }
